@@ -105,6 +105,15 @@ class TestBigQuery(Validator):
                 "spark": "x IS NULL",
             },
         )
+        self.validate_all(
+            "CURRENT_DATE",
+            read={
+                "tsql": "GETDATE()",
+            },
+            write={
+                "tsql": "GETDATE()",
+            },
+        )
         self.validate_all(
             "current_datetime",
             write={
