@@ -8,6 +8,8 @@ class TestClickhouse(Validator):
         self.validate_identity("dictGet(x, 'y')")
         self.validate_identity("SELECT * FROM x FINAL")
         self.validate_identity("SELECT * FROM x AS y FINAL")
+        self.validate_identity("'a' IN mapKeys(map('a', 1, 'b', 2))")
+        self.validate_identity("CAST((1, 2) AS Tuple(a Int8, b Int16))")
 
         self.validate_all(
             "SELECT fname, lname, age FROM person ORDER BY age DESC NULLS FIRST, fname ASC NULLS LAST, lname",
@@ -20,6 +22,12 @@ class TestClickhouse(Validator):
         self.validate_all(
             "CAST(1 AS NULLABLE(Int64))",
             write={
-                "clickhouse": "CAST(1 AS Nullable(BIGINT))",
+                "clickhouse": "CAST(1 AS Nullable(Int64))",
+            },
+        )
+        self.validate_all(
+            "CAST(1 AS Nullable(DateTime64(6, 'UTC')))",
+            write={
+                "clickhouse": "CAST(1 AS Nullable(DateTime64(6, 'UTC')))",
             },
         )
