@@ -52,6 +52,9 @@ TRUE;
 NULL AND TRUE;
 NULL;
 
+NULL AND FALSE;
+FALSE;
+
 NULL AND NULL;
 NULL;
 
@@ -70,6 +73,9 @@ FALSE;
 NOT FALSE;
 TRUE;
 
+NOT NULL;
+NULL;
+
 NULL = NULL;
 NULL;
 
